#!/usr/bin/perl -w
use strict;
use MDK::Common qw(mkdir_p);
use File::Find;

# This scripts saves the kde mimetype associations that the
# user set up in ~/.local/share/applications/Mandrakelinux/ into a file
# (/tmp/update-menu-<uid>-kdemimetypes)
# This is used by restorekdemimetypes.sh to restore the
# associations after update-menu has run.

# 06/09/2000: Initial Version. David Faure <david@mandrakesoft.com>
# 05/04/2001: Ported to perl, path on the command line (DF)

my $msg = "Running 2 savekdemimetypes.pl" . join(', ', @ARGV) . "\n";
warn $msg;

if ($#ARGV != 0) {
  print STDERR "Usage : savekdemimetypes.pl ....../share/applications/Mandrakelinux/ (either user or global)\n";
  exit 1;
}

## This is the perl equivalent of:
##  find . -type f -exec egrep -H 'ServiceTypes|MimeType' {} \;> /tmp/update-menu-$UID-kdemimetypes

my $basepath=$ARGV[0];

# Laurent Create tmp if it doesn't exist
mkdir_p("$ENV{HOME}/tmp/");
my $dest_file = "$ENV{HOME}/tmp/update-menu-$<-kdemimetypes";
open(my $FILEDEST, ">$dest_file") or die "cannot create $dest_file\n";

sub process_file {
  if (-f $_)
    {
      my $file = $File::Find::name;
      my $data = "";
      #print STDERR "Processing $file\n";
      
      open(my $FILEIN, "<$file") or do {
			  warn "skipping file \"$file\" (cannot open it)\n";
			  return;
	  };
      seek($FILEIN, 0, 2);
      my $fsize = tell($FILEIN);
      seek($FILEIN, 0, 0);
      read $FILEIN, $data, $fsize;
      close($FILEIN);
      # Copy the MimeType and ServiceTypes line from that file
      print $FILEDEST $file . "::$1\n" if $data =~ /\n(ServiceTypes[ \t]*=[ \t]*[^\n]*)\n/;
      print $FILEDEST $file . "::$1\n" if $data =~ /\n(MimeType[ \t]*=[ \t]*[^\n]*)\n/;
    }
}

File::Find::find(\&process_file, $ARGV[0]) if -e $ARGV[0];

close $FILEDEST;

